@@ -17,7 +17,8 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_codepipeline.paginator import (
+from .literals import ActionCategoryType, ActionOwnerType, StageTransitionTypeType
+from .paginator import (
     ListActionExecutionsPaginator,
     ListActionTypesPaginator,
     ListPipelineExecutionsPaginator,
@@ -25,8 +26,6 @@ from mypy_boto3_codepipeline.paginator import (
     ListTagsForResourcePaginator,
     ListWebhooksPaginator,
 )
-
-from .literals import ActionCategory, ActionOwner, StageTransitionType
 from .type_defs import (
     AcknowledgeJobOutputTypeDef,
     AcknowledgeThirdPartyJobOutputTypeDef,
@@ -129,7 +128,7 @@ class Exceptions:
 
 class CodePipelineClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -138,27 +137,27 @@ class CodePipelineClient:
 
     def acknowledge_job(self, jobId: str, nonce: str) -> AcknowledgeJobOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_job)
-        [Show boto3-stubs documentation](./client.md#acknowledge-job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_job)
+        [Show boto3-stubs documentation](./client.md#acknowledge_job)
         """
 
     def acknowledge_third_party_job(
         self, jobId: str, nonce: str, clientToken: str
     ) -> AcknowledgeThirdPartyJobOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_third_party_job)
-        [Show boto3-stubs documentation](./client.md#acknowledge-third-party-job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_third_party_job)
+        [Show boto3-stubs documentation](./client.md#acknowledge_third_party_job)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_custom_action_type(
         self,
-        category: ActionCategory,
+        category: ActionCategoryType,
         provider: str,
         version: str,
         inputArtifactDetails: "ArtifactDetailsTypeDef",
@@ -168,58 +167,62 @@ class CodePipelineClient:
         tags: List["TagTypeDef"] = None,
     ) -> CreateCustomActionTypeOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.create_custom_action_type)
-        [Show boto3-stubs documentation](./client.md#create-custom-action-type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.create_custom_action_type)
+        [Show boto3-stubs documentation](./client.md#create_custom_action_type)
         """
 
     def create_pipeline(
         self, pipeline: "PipelineDeclarationTypeDef", tags: List["TagTypeDef"] = None
     ) -> CreatePipelineOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.create_pipeline)
-        [Show boto3-stubs documentation](./client.md#create-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.create_pipeline)
+        [Show boto3-stubs documentation](./client.md#create_pipeline)
         """
 
     def delete_custom_action_type(
-        self, category: ActionCategory, provider: str, version: str
+        self, category: ActionCategoryType, provider: str, version: str
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.delete_custom_action_type)
-        [Show boto3-stubs documentation](./client.md#delete-custom-action-type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.delete_custom_action_type)
+        [Show boto3-stubs documentation](./client.md#delete_custom_action_type)
         """
 
     def delete_pipeline(self, name: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.delete_pipeline)
-        [Show boto3-stubs documentation](./client.md#delete-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.delete_pipeline)
+        [Show boto3-stubs documentation](./client.md#delete_pipeline)
         """
 
     def delete_webhook(self, name: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.delete_webhook)
-        [Show boto3-stubs documentation](./client.md#delete-webhook)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.delete_webhook)
+        [Show boto3-stubs documentation](./client.md#delete_webhook)
         """
 
     def deregister_webhook_with_third_party(self, webhookName: str = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.deregister_webhook_with_third_party)
-        [Show boto3-stubs documentation](./client.md#deregister-webhook-with-third-party)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.deregister_webhook_with_third_party)
+        [Show boto3-stubs documentation](./client.md#deregister_webhook_with_third_party)
         """
 
     def disable_stage_transition(
-        self, pipelineName: str, stageName: str, transitionType: StageTransitionType, reason: str
+        self,
+        pipelineName: str,
+        stageName: str,
+        transitionType: StageTransitionTypeType,
+        reason: str,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.disable_stage_transition)
-        [Show boto3-stubs documentation](./client.md#disable-stage-transition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.disable_stage_transition)
+        [Show boto3-stubs documentation](./client.md#disable_stage_transition)
         """
 
     def enable_stage_transition(
-        self, pipelineName: str, stageName: str, transitionType: StageTransitionType
+        self, pipelineName: str, stageName: str, transitionType: StageTransitionTypeType
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.enable_stage_transition)
-        [Show boto3-stubs documentation](./client.md#enable-stage-transition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.enable_stage_transition)
+        [Show boto3-stubs documentation](./client.md#enable_stage_transition)
         """
 
     def generate_presigned_url(
@@ -230,50 +233,50 @@ class CodePipelineClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_action_type(
-        self, category: ActionCategory, owner: str, provider: str, version: str
+        self, category: ActionCategoryType, owner: str, provider: str, version: str
     ) -> GetActionTypeOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.get_action_type)
-        [Show boto3-stubs documentation](./client.md#get-action-type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.get_action_type)
+        [Show boto3-stubs documentation](./client.md#get_action_type)
         """
 
     def get_job_details(self, jobId: str) -> GetJobDetailsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.get_job_details)
-        [Show boto3-stubs documentation](./client.md#get-job-details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.get_job_details)
+        [Show boto3-stubs documentation](./client.md#get_job_details)
         """
 
     def get_pipeline(self, name: str, version: int = None) -> GetPipelineOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline)
-        [Show boto3-stubs documentation](./client.md#get-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline)
+        [Show boto3-stubs documentation](./client.md#get_pipeline)
         """
 
     def get_pipeline_execution(
         self, pipelineName: str, pipelineExecutionId: str
     ) -> GetPipelineExecutionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_execution)
-        [Show boto3-stubs documentation](./client.md#get-pipeline-execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_execution)
+        [Show boto3-stubs documentation](./client.md#get_pipeline_execution)
         """
 
     def get_pipeline_state(self, name: str) -> GetPipelineStateOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_state)
-        [Show boto3-stubs documentation](./client.md#get-pipeline-state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_state)
+        [Show boto3-stubs documentation](./client.md#get_pipeline_state)
         """
 
     def get_third_party_job_details(
         self, jobId: str, clientToken: str
     ) -> GetThirdPartyJobDetailsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.get_third_party_job_details)
-        [Show boto3-stubs documentation](./client.md#get-third-party-job-details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.get_third_party_job_details)
+        [Show boto3-stubs documentation](./client.md#get_third_party_job_details)
         """
 
     def list_action_executions(
@@ -284,48 +287,51 @@ class CodePipelineClient:
         nextToken: str = None,
     ) -> ListActionExecutionsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.list_action_executions)
-        [Show boto3-stubs documentation](./client.md#list-action-executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.list_action_executions)
+        [Show boto3-stubs documentation](./client.md#list_action_executions)
         """
 
     def list_action_types(
-        self, actionOwnerFilter: ActionOwner = None, nextToken: str = None, regionFilter: str = None
+        self,
+        actionOwnerFilter: ActionOwnerType = None,
+        nextToken: str = None,
+        regionFilter: str = None,
     ) -> ListActionTypesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.list_action_types)
-        [Show boto3-stubs documentation](./client.md#list-action-types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.list_action_types)
+        [Show boto3-stubs documentation](./client.md#list_action_types)
         """
 
     def list_pipeline_executions(
         self, pipelineName: str, maxResults: int = None, nextToken: str = None
     ) -> ListPipelineExecutionsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.list_pipeline_executions)
-        [Show boto3-stubs documentation](./client.md#list-pipeline-executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.list_pipeline_executions)
+        [Show boto3-stubs documentation](./client.md#list_pipeline_executions)
         """
 
     def list_pipelines(
         self, nextToken: str = None, maxResults: int = None
     ) -> ListPipelinesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.list_pipelines)
-        [Show boto3-stubs documentation](./client.md#list-pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.list_pipelines)
+        [Show boto3-stubs documentation](./client.md#list_pipelines)
         """
 
     def list_tags_for_resource(
         self, resourceArn: str, nextToken: str = None, maxResults: int = None
     ) -> ListTagsForResourceOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def list_webhooks(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListWebhooksOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.list_webhooks)
-        [Show boto3-stubs documentation](./client.md#list-webhooks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.list_webhooks)
+        [Show boto3-stubs documentation](./client.md#list_webhooks)
         """
 
     def poll_for_jobs(
@@ -335,16 +341,16 @@ class CodePipelineClient:
         queryParam: Dict[str, str] = None,
     ) -> PollForJobsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.poll_for_jobs)
-        [Show boto3-stubs documentation](./client.md#poll-for-jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.poll_for_jobs)
+        [Show boto3-stubs documentation](./client.md#poll_for_jobs)
         """
 
     def poll_for_third_party_jobs(
         self, actionTypeId: "ActionTypeIdTypeDef", maxBatchSize: int = None
     ) -> PollForThirdPartyJobsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.poll_for_third_party_jobs)
-        [Show boto3-stubs documentation](./client.md#poll-for-third-party-jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.poll_for_third_party_jobs)
+        [Show boto3-stubs documentation](./client.md#poll_for_third_party_jobs)
         """
 
     def put_action_revision(
@@ -355,8 +361,8 @@ class CodePipelineClient:
         actionRevision: "ActionRevisionTypeDef",
     ) -> PutActionRevisionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.put_action_revision)
-        [Show boto3-stubs documentation](./client.md#put-action-revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.put_action_revision)
+        [Show boto3-stubs documentation](./client.md#put_action_revision)
         """
 
     def put_approval_result(
@@ -368,14 +374,14 @@ class CodePipelineClient:
         token: str,
     ) -> PutApprovalResultOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.put_approval_result)
-        [Show boto3-stubs documentation](./client.md#put-approval-result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.put_approval_result)
+        [Show boto3-stubs documentation](./client.md#put_approval_result)
         """
 
     def put_job_failure_result(self, jobId: str, failureDetails: FailureDetailsTypeDef) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.put_job_failure_result)
-        [Show boto3-stubs documentation](./client.md#put-job-failure-result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.put_job_failure_result)
+        [Show boto3-stubs documentation](./client.md#put_job_failure_result)
         """
 
     def put_job_success_result(
@@ -387,16 +393,16 @@ class CodePipelineClient:
         outputVariables: Dict[str, str] = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.put_job_success_result)
-        [Show boto3-stubs documentation](./client.md#put-job-success-result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.put_job_success_result)
+        [Show boto3-stubs documentation](./client.md#put_job_success_result)
         """
 
     def put_third_party_job_failure_result(
         self, jobId: str, clientToken: str, failureDetails: FailureDetailsTypeDef
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_failure_result)
-        [Show boto3-stubs documentation](./client.md#put-third-party-job-failure-result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_failure_result)
+        [Show boto3-stubs documentation](./client.md#put_third_party_job_failure_result)
         """
 
     def put_third_party_job_success_result(
@@ -408,22 +414,22 @@ class CodePipelineClient:
         executionDetails: ExecutionDetailsTypeDef = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_success_result)
-        [Show boto3-stubs documentation](./client.md#put-third-party-job-success-result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_success_result)
+        [Show boto3-stubs documentation](./client.md#put_third_party_job_success_result)
         """
 
     def put_webhook(
         self, webhook: "WebhookDefinitionTypeDef", tags: List["TagTypeDef"] = None
     ) -> PutWebhookOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.put_webhook)
-        [Show boto3-stubs documentation](./client.md#put-webhook)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.put_webhook)
+        [Show boto3-stubs documentation](./client.md#put_webhook)
         """
 
     def register_webhook_with_third_party(self, webhookName: str = None) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.register_webhook_with_third_party)
-        [Show boto3-stubs documentation](./client.md#register-webhook-with-third-party)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.register_webhook_with_third_party)
+        [Show boto3-stubs documentation](./client.md#register_webhook_with_third_party)
         """
 
     def retry_stage_execution(
@@ -434,50 +440,50 @@ class CodePipelineClient:
         retryMode: Literal["FAILED_ACTIONS"],
     ) -> RetryStageExecutionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.retry_stage_execution)
-        [Show boto3-stubs documentation](./client.md#retry-stage-execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.retry_stage_execution)
+        [Show boto3-stubs documentation](./client.md#retry_stage_execution)
         """
 
     def start_pipeline_execution(
         self, name: str, clientRequestToken: str = None
     ) -> StartPipelineExecutionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.start_pipeline_execution)
-        [Show boto3-stubs documentation](./client.md#start-pipeline-execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.start_pipeline_execution)
+        [Show boto3-stubs documentation](./client.md#start_pipeline_execution)
         """
 
     def stop_pipeline_execution(
         self, pipelineName: str, pipelineExecutionId: str, abandon: bool = None, reason: str = None
     ) -> StopPipelineExecutionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.stop_pipeline_execution)
-        [Show boto3-stubs documentation](./client.md#stop-pipeline-execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.stop_pipeline_execution)
+        [Show boto3-stubs documentation](./client.md#stop_pipeline_execution)
         """
 
     def tag_resource(self, resourceArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_action_type(self, actionType: "ActionTypeDeclarationTypeDef") -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.update_action_type)
-        [Show boto3-stubs documentation](./client.md#update-action-type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.update_action_type)
+        [Show boto3-stubs documentation](./client.md#update_action_type)
         """
 
     def update_pipeline(
         self, pipeline: "PipelineDeclarationTypeDef"
     ) -> UpdatePipelineOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Client.update_pipeline)
-        [Show boto3-stubs documentation](./client.md#update-pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Client.update_pipeline)
+        [Show boto3-stubs documentation](./client.md#update_pipeline)
         """
 
     @overload
@@ -485,7 +491,7 @@ class CodePipelineClient:
         self, operation_name: Literal["list_action_executions"]
     ) -> ListActionExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)[Show boto3-stubs documentation](./paginators.md#listactionexecutionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)[Show boto3-stubs documentation](./paginators.md#listactionexecutionspaginator)
         """
 
     @overload
@@ -493,7 +499,7 @@ class CodePipelineClient:
         self, operation_name: Literal["list_action_types"]
     ) -> ListActionTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)[Show boto3-stubs documentation](./paginators.md#listactiontypespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)[Show boto3-stubs documentation](./paginators.md#listactiontypespaginator)
         """
 
     @overload
@@ -501,13 +507,13 @@ class CodePipelineClient:
         self, operation_name: Literal["list_pipeline_executions"]
     ) -> ListPipelineExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)[Show boto3-stubs documentation](./paginators.md#listpipelineexecutionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)[Show boto3-stubs documentation](./paginators.md#listpipelineexecutionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)[Show boto3-stubs documentation](./paginators.md#listpipelinespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)[Show boto3-stubs documentation](./paginators.md#listpipelinespaginator)
         """
 
     @overload
@@ -515,11 +521,11 @@ class CodePipelineClient:
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)[Show boto3-stubs documentation](./paginators.md#listtagsforresourcepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)[Show boto3-stubs documentation](./paginators.md#listtagsforresourcepaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_webhooks"]) -> ListWebhooksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)[Show boto3-stubs documentation](./paginators.md#listwebhookspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)[Show boto3-stubs documentation](./paginators.md#listwebhookspaginator)
         """
