@@ -32,7 +32,7 @@ from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from .literals import ActionOwner
+from .literals import ActionOwnerType
 from .type_defs import (
     ActionExecutionFilterTypeDef,
     ListActionExecutionsOutputTypeDef,
@@ -56,7 +56,7 @@ __all__ = (
 
 class ListActionExecutionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)[Show boto3-stubs documentation](./paginators.md#listactionexecutionspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)[Show boto3-stubs documentation](./paginators.md#listactionexecutionspaginator)
     """
 
     def paginate(
@@ -66,79 +66,79 @@ class ListActionExecutionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListActionExecutionsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions.paginate)
         [Show boto3-stubs documentation](./paginators.md#listactionexecutionspaginator)
         """
 
 
 class ListActionTypesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)[Show boto3-stubs documentation](./paginators.md#listactiontypespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)[Show boto3-stubs documentation](./paginators.md#listactiontypespaginator)
     """
 
     def paginate(
         self,
-        actionOwnerFilter: ActionOwner = None,
+        actionOwnerFilter: ActionOwnerType = None,
         regionFilter: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListActionTypesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes.paginate)
         [Show boto3-stubs documentation](./paginators.md#listactiontypespaginator)
         """
 
 
 class ListPipelineExecutionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)[Show boto3-stubs documentation](./paginators.md#listpipelineexecutionspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)[Show boto3-stubs documentation](./paginators.md#listpipelineexecutionspaginator)
     """
 
     def paginate(
         self, pipelineName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListPipelineExecutionsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions.paginate)
         [Show boto3-stubs documentation](./paginators.md#listpipelineexecutionspaginator)
         """
 
 
 class ListPipelinesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)[Show boto3-stubs documentation](./paginators.md#listpipelinespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)[Show boto3-stubs documentation](./paginators.md#listpipelinespaginator)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListPipelinesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines.paginate)
         [Show boto3-stubs documentation](./paginators.md#listpipelinespaginator)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)[Show boto3-stubs documentation](./paginators.md#listtagsforresourcepaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)[Show boto3-stubs documentation](./paginators.md#listtagsforresourcepaginator)
     """
 
     def paginate(
         self, resourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTagsForResourceOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource.paginate)
         [Show boto3-stubs documentation](./paginators.md#listtagsforresourcepaginator)
         """
 
 
 class ListWebhooksPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)[Show boto3-stubs documentation](./paginators.md#listwebhookspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)[Show boto3-stubs documentation](./paginators.md#listwebhookspaginator)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListWebhooksOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks.paginate)
         [Show boto3-stubs documentation](./paginators.md#listwebhookspaginator)
         """
